@@ -6,7 +6,7 @@
 ;; Homepage: https://github.com/magit/ghub
 ;; Keywords: tools
 
-;; Package-Version: 5.0.0
+;; Package-Version: 5.0.1
 ;; Package-Requires: (
 ;;     (emacs   "29.1")
 ;;     (compat  "30.1")
@@ -783,8 +783,7 @@ or (info \"(ghub)Getting Started\") for instructions."
 
 (defun ghub--auth-source-get (keys &rest spec)
   (declare (indent 1))
-  (if-let ((plist (car (apply #'auth-source-search
-                              (append spec (list :max 1))))))
+  (if-let ((plist (car (apply #'auth-source-search spec))))
       (if (keywordp keys)
           (plist-get plist keys)
         (mapcar (##plist-get plist %) keys))
@@ -794,6 +793,14 @@ or (info \"(ghub)Getting Started\") for instructions."
     (auth-source-forget spec)
     nil))
 
+(define-advice auth-source-netrc-parse (:around (fn &rest args) handle-symlink)
+  "Follow symlinks for FILE before comparing modification times."
+  (let ((file (plist-get args :file)))
+    (when (and (stringp file)
+               (file-exists-p file))
+      (setq args (plist-put args :file (file-chase-links file)))))
+  (apply fn args))
+
 (defun ghub--git-get (var)
   (catch 'non-zero
     (car (process-lines-handling-status
